pub enum NativeError {
WindowCreation(String),
GpuInit(String),
DiffEmpty,
WindowDestroyed(WindowId),
EventLoop(String),
}Expand description
Errors that can occur in the native rendering backend.
Variants
WindowCreation(String)
Window creation failed (e.g., display server unavailable).
GpuInit(String)
GPU initialization failed (e.g., driver issues).
DiffEmpty
VDom diff produced no patches but a rebuild was expected. This is a bug.
WindowDestroyed(WindowId)
A window was destroyed but events are still being dispatched.
EventLoop(String)
An error occurred in the event loop.