Module main_loop

Module main_loop 

Structs

App
ShieldWall

Enums

AppEvent
Custom events for the native application event loop, handling accessibility callbacks and routing window lifecycle control events from background threads.