pub struct ShieldWall { /* private fields */ }Trait Implementations
Sourceimpl ActionHandler for ShieldWall
impl ActionHandler for ShieldWall
Sourcefn do_action(&mut self, request: ActionRequest)
fn do_action(&mut self, request: ActionRequest)
Perform the requested action. If the requested action is not supported,
this method must do nothing. Read more
Sourceimpl ActivationHandler for ShieldWall
impl ActivationHandler for ShieldWall
Sourcefn request_initial_tree(&mut self) -> Option<TreeUpdate>
fn request_initial_tree(&mut self) -> Option<TreeUpdate>
Requests a
TreeUpdate with a full tree. If the application
can generate the tree synchronously within this method call,
it should do so and return the TreeUpdate. Otherwise,
it must send the update to the platform adapter asynchronously,
no later than the next display refresh, even if a frame would not
normally be rendered due to user input or other activity.
The application should not return or send a placeholder TreeUpdate;
the platform adapter will provide one if necessary until the real
tree is sent. Read moreSourceimpl DeactivationHandler for ShieldWall
impl DeactivationHandler for ShieldWall
Sourcefn deactivate_accessibility(&mut self)
fn deactivate_accessibility(&mut self)
Deactivate the application’s accessibility implementation and drop any
associated data that can be reconstructed later. After this method
is called, if an accessibility tree is needed again, the platform
adapter will call
ActivationHandler::request_initial_tree again. Read moreAuto Trait Implementations
impl Freeze for ShieldWall
impl RefUnwindSafe for ShieldWall
impl Send for ShieldWall
impl Sync for ShieldWall
impl Unpin for ShieldWall
impl UnsafeUnpin for ShieldWall
impl UnwindSafe for ShieldWall