pub struct WindowManager {
pub windows: HashMap<WindowId, WindowData>,
pub window_stack: Vec<WindowId>,
pub winit_to_core: HashMap<WindowId, WindowId>,
pub core_to_winit: HashMap<WindowId, WindowId>,
pub next_core_id: u64,
}Expand description
Dynamic manager for all active native windows and their rendering contexts.
Fields
windows: HashMap<WindowId, WindowData>Mapping from native winit WindowId to internal WindowData.
window_stack: Vec<WindowId>Stack of windows ordered from back to front (end of vector is top-most).
winit_to_core: HashMap<WindowId, WindowId>Mapping of winit window IDs to core IDs.
core_to_winit: HashMap<WindowId, WindowId>Mapping of core window IDs to winit IDs.
next_core_id: u64Monotonic counter to allocate unique core window IDs.
Implementations
Sourceimpl WindowManager
impl WindowManager
Sourcepub fn create_window(
&mut self,
event_loop: &ActiveEventLoop,
gpu: &Option<Arc<Mutex<SurtrRenderer>>>,
proxy: EventLoopProxy<AppEvent>,
config: WindowConfig,
is_main: bool,
view: &impl View,
) -> WindowHandle
pub fn create_window( &mut self, event_loop: &ActiveEventLoop, gpu: &Option<Arc<Mutex<SurtrRenderer>>>, proxy: EventLoopProxy<AppEvent>, config: WindowConfig, is_main: bool, view: &impl View, ) -> WindowHandle
Create and register a new native window.
Sourcepub fn close_window(&mut self, winit_id: WindowId)
pub fn close_window(&mut self, winit_id: WindowId)
Close and unregister a native window.
Sourcepub fn bring_to_front(&mut self, winit_id: WindowId)
pub fn bring_to_front(&mut self, winit_id: WindowId)
Bring a native window to the foreground and focus it.
Sourcepub fn window(&self, winit_id: WindowId) -> Option<&WindowData>
pub fn window(&self, winit_id: WindowId) -> Option<&WindowData>
Get a reference to a window’s data.
Sourcepub fn window_mut(&mut self, winit_id: WindowId) -> Option<&mut WindowData>
pub fn window_mut(&mut self, winit_id: WindowId) -> Option<&mut WindowData>
Get a mutable reference to a window’s data.
Sourcepub fn window_order(&self) -> &[WindowId]
pub fn window_order(&self) -> &[WindowId]
Return the list of window IDs in current Z-order stack.