Module window

Module window 

Structs

MonitorConfig
Monitor configuration.
MultiMonitorManager
Manages multi-monitor layouts.
NativeWindowWrapper
Native implementation of the cvkg_core::Window trait.
ResizeHitTest
Hit-test helper for resize handles on windows with rounded corners.
SafeAreaInsets
Platform safe area insets (menu bar, notch, etc.).
WindowCapabilityMatrix
Window capability matrix per platform.
WindowData
WindowManager
Dynamic manager for all active native windows and their rendering contexts.
WindowStateDetector
Tracks the current WindowState based on incoming winit WindowEvents.

Enums

WindowState
Represents the current state of a window.
WindowType
Window type.