cvkg-render-native 0.1.16

Cyber Viking Kvasir Graph (CVKG) - High-fidelity agentic UI framework
docs.rs failed to build cvkg-render-native-0.1.16
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: cvkg-render-native-0.1.22

cvkg-render-native

cvkg-render-native provides OS-level integration for CVKG applications on Desktop (Linux, Windows, macOS).

🚀 Quick Start

use cvkg_render_native::run_app;
use cvkg_components::{Text, VStack, Button};
use cvkg_core::View;

fn main() {
    run_app(