Module main_loop
cvkg_
render_
native
0.3.0
Module main_
loop
Module Items
Structs
Enums
In crate cvkg_
render_
native
cvkg_render_native
Module
main_
loop
Structs

App
Shield
Wall
Enums

AppEvent
Custom events for the native application event loop, handling accessibility callbacks and routing window lifecycle control events from background threads.