Structs
- Monitor
Config - Monitor configuration.
- Multi
Monitor Manager - Manages multi-monitor layouts.
- Native
Window Wrapper - Native implementation of the cvkg_core::Window trait.
- Resize
HitTest - Hit-test helper for resize handles on windows with rounded corners.
- Safe
Area Insets - Platform safe area insets (menu bar, notch, etc.).
- Window
Capability Matrix - Window capability matrix per platform.
- Window
Data - Window
Manager - Dynamic manager for all active native windows and their rendering contexts.
- Window
State Detector - Tracks the current
WindowStatebased on incoming winitWindowEvents.
Enums
- Window
State - Represents the current state of a window.
- Window
Type - Window type.